@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Exporter qw/import/;
 
-our $VERSION   = q{0.91};
+our $VERSION   = q{0.92};
 our @EXPORT    = qw(dispatch on);
 our @EXPORT_OK = qw(dispatch on);
 
@@ -71,19 +71,22 @@ Dispatch::Fu - Provides a reduction based approach to given/when or variable dis
 
 =head1 DESCRIPTION
 
-C<Dispatch::Fu> provides an idomatic and succinct way to organize a C<HASH>-based
-dispatch table.
+C<Dispatch::Fu> provides an idiomatic and succinct way to organize a C<HASH>-based
+dispatch table by first computing a static key using a developer defined process.
 
 =head2 The Problem 
 
-A dispatch table can be fashioned easily when the dispatch may occur on a single
-variable that may be one or more static strings suitable to serve also as C<HASH>
-a key.
+C<HASH> based dispatching in Perl is a very fast and well established way
+to organize your code.  A dispatch table can be fashioned easily when the
+dispatch may occur on a single variable that may be one or more static
+strings suitable to serve also as C<HASH> a key.
 
-For example, the following is more or less a classical expampe of this approach:
+For example, the following is more or less a classical example of this approach
+that is fundamentally based on a 1:1 mapping of a value of C<$action> to a C<HASH>
+key defined in C<$dispatch>:
 
-  my $action = get_action();
-  
+  my $action = get_action(); # presumed to return one of the hash keys used below
+   
   my $dispatch = {
     do_dis     => sub { ... },
     do_dat     => sub { ... },
@@ -91,10 +94,10 @@ For example, the following is more or less a classical expampe of this approach:
     do_doze    => sub { ... },
   }; 
    
-  if ($action or not exists $dispatch->{$action}) {
+  if (not $action or not exists $dispatch->{$action}) {
     die qq{action not supported\n};
   }
-
+  
   my $results = $dispatch->{$action}->();
 
 But this nice situation breaks down if C<$action> is a value that is
@@ -109,10 +112,11 @@ C<Dispatch::Fu> solves the problem by providing a I<Perlish> and I<idiomatic>
 hook for computing a static key from an arbitrarily defined algorithm
 written by the developer using this module.
 
-The static key that is computed is then used to do to dispatch the anonyous
-subroutine explicitly defined but that key.
+The `dispatch` keyword and associated lexical block (I<that should be treated
+as the body of a subroutine that receives exactly one parameter>), determines
+what I<case> defined by the C<on> keyword is immediately executed.
 
-The simple case above can be mostly replicated below:
+The simple case above can be trivially replicated below:
 
   my $results = dispatch {
     my $_action = shift;
@@ -153,6 +157,11 @@ Similarly, a more complicate case might be defined:
    on do_deez   => sub { ... },
    on do_doze   => sub { ... }; # semi-colon
 
+The approach facilited by C<Dispatch::Fu> is one that requires the programmer
+to define each case by a static key via C<on>, and define a custom algorithm
+for picking which case (by way of returning the correct static key as a string)
+to execute via C<dispatch>.
+
 =head1 USAGE
 
 The developer using this module defines how to boil down the provided
@@ -188,8 +197,9 @@ added using the C<on> keyword.
 
 =item C<REF>
 
-This is the scalar reference that contains all the stuff to be used in the
-C<dispatch> BLOCK. In the example above it is, C<$bar>.
+This is the singular scalar reference that contains all the stuff to be used
+in the C<dispatch> BLOCK. In the example above it is, C<[rand 10]>. It is
+the way to pass arbitrary data into C<dispatch>. E.g.,
 
   my $_ref = [qw/foo bar baz 1 3 4 5/];
   dispatch {
@@ -208,7 +218,7 @@ a subroutine reference. In order for this to work for you, the C<dispatch>
 BLOCK must return strictly only the keys that are defined via C<on>.
 
   my $input_ref = [qw/foo bar baz 1 3 4 5/];
-  
+    
   dispatch {
     my ($ref)    = @_;          # there is only one parameter, but can a reference to anything
     my $key      = q{default};  # initiate the default key to use, 'default' by convention not required
@@ -223,16 +233,16 @@ BLOCK must return strictly only the keys that are defined via C<on>.
    on q{key4}    => sub {...},
    on q{key5}    => sub {...};  # <~ last line of the construct must end with a semicolon, like all Perl statements
 
-Note: Currently, there is no way to specific the input parameters into the
-subroutine reference that is added by each C<on> statement. This means that
-the subroutine refs are to be treated as wrappers that access the current
-scope. This provides maximum flexibility and allows one to manage what
-happens in each C<on> case more explicitly.
-
-For example,
+Note: It was made as a design decision that there be no way to specify the
+input parameters into the subroutine reference that is added by each C<on>
+statement. This means that the subroutine refs are to be treated as wrappers
+that access the current scope. This provides maximum flexibility and allows
+one to manage what happens in each C<on> case more explicitly. Perl's scoping
+rules lets one use variables in a higher scope, so that would be the way to
+deal with it. E.g.,
 
   my $input_ref  = [qw/foo bar baz 1 3 4 5/];
-  
+   
   dispatch {
     my ($ref)    = @_;
     my $key      = q{default};
@@ -246,6 +256,11 @@ For example,
 
 =back
 
+=head1 BUGS
+
+Please report any bugs or ideas about making this module an even better
+basis for doing dynamic dispatching.
+
 =head1 AUTHOR
 
 O. ODLER 558 L<< <oodler@cpan.org> >>.
